from django.contrib import admin


class EditorAdminMixin:
    class Media:
        js = (
            "kindeditor/kindeditor-all.min.js",
            "kindeditor/lang/zh-CN.min.js",
            "kindeditor/config.min.js",
        )


class EditorAdmin(admin.ModelAdmin, EditorAdminMixin):
    pass



from django.conf import settings
from django.db import models

DEFAULT_UPLOAD_TO = "upload/%Y/%m/"


class UploadImage(models.Model):
    img = models.ImageField(
        upload_to=getattr(settings, "KINDEDITOR_UPLOAD_TO", DEFAULT_UPLOAD_TO)
    )



from django import forms
from django.core.serializers.json import DjangoJSONEncoder
from django.forms.utils import flatatt
from django.template.loader import render_to_string
from django.utils.encoding import force_text
from django.utils.functional import Promise
from django.utils.html import conditional_escape
from django.utils.safestring import mark_safe
from django.utils.translation import get_language


class LazyEncoder(DjangoJSONEncoder):
    def default(self, obj):
        if isinstance(obj, Promise):
            return force_text(obj)
        return super().default(obj)


json_encode = LazyEncoder().encode

DEFAULT_CONFIG = {}


class KindeditorWidget(forms.Textarea):
    """
    Widget providing kindeditor for Rich Text Editing.
    Supports direct image uploads and embed.
    """

    class Media:
        js = (
            "kindeditor/kindeditor-all.min.js",
            "kindeditor/lang/zh-CN.min.js",
            "kindeditor/config.min.js",
        )

    def __init__(
        self,
        config_name="default",
        extra_plugins=None,
        external_plugin_resources=None,
        *args,
        **kwargs
    ):
        super().__init__(*args, **kwargs)
        self.config = DEFAULT_CONFIG.copy()
        self.external_plugin_resources = external_plugin_resources or []

    def render(self, name, value, attrs=None, renderer=None):
        if value is None:
            value = ""
        final_attrs = self.build_attrs(self.attrs, attrs, name=name)
        self._set_config()
        external_plugin_resources = [
            [force_text(a), force_text(b), force_text(c)]
            for a, b, c in self.external_plugin_resources
        ]
        return mark_safe(
            render_to_string(
                "kindeditor/widget.html",
                {
                    "final_attrs": flatatt(final_attrs),
                    "value": conditional_escape(force_text(value)),
                    "id": final_attrs["id"],
                    "config": json_encode(self.config),
                    "external_plugin_resources": json_encode(
                        external_plugin_resources
                    ),
                },
            )
        )

    def build_attrs(self, base_attrs, extra_attrs=None, **kwargs):
        attrs = dict(base_attrs, **kwargs)
        if extra_attrs:
            attrs.update(extra_attrs)
        return attrs

    def _set_config(self):
        lang = get_language()
        if lang == "zh-hans":
            lang = "zh-cn"
        self.config["language"] = lang



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import shutil
import sys
from io import open

from setuptools import setup

here = os.path.abspath(os.path.dirname(__file__))


def read(f):
    return open(f, "r", encoding="utf-8").read()


about = {}
exec(read(os.path.join(here, "kindeditor", "__version__.py")), about)

# 'setup.py publish' shortcut.
if sys.argv[-1] == "publish":
    if os.system("which twine"):
        print("twine not installed.\nUse `pip install twine`.\nExiting.")
        sys.exit()
    os.system("python setup.py sdist bdist_wheel")
    os.system("twine upload dist/*")
    print("You probably want to also tag the version now:")
    print("  git tag -a {0} -m 'version {0}'".format(about["__version__"]))
    print("  git push --tags")
    shutil.rmtree("dist")
    shutil.rmtree("build")
    shutil.rmtree("django_kindeditor.egg-info")
    sys.exit()

packages = ["kindeditor"]

requires = ["django>=2.0", "pillow>=5.3"]


readme = read("README.md")

setup(
    name=about["__title__"],
    version=about["__version__"],
    description=about["__description__"],
    long_description=readme,
    long_description_content_type="text/markdown",
    author=about["__author__"],
    author_email=about["__author_email__"],
    url=about["__url__"],
    license=about["__license__"],
    packages=packages,
    include_package_data=True,
    install_requires=requires,
    python_requires=">=3.6",
    zip_safe=False,
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Environment :: Web Environment",
        "Framework :: Django",
        "Framework :: Django :: 2.0",
        "Framework :: Django :: 2.1",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Topic :: Internet :: WWW/HTTP",
    ],
)



from django import forms
from django.conf import settings
from django.core.exceptions import PermissionDenied
from django.http import JsonResponse
from django.utils.translation import gettext as _
from django.views import View

from .models import UploadImage

HTTP_201_CREATED = 201
HTTP_400_BAD_REQUEST = 400
IsAuthenticated = 1
IsAdminUser = 10

SETTINGS_PERMISSION_MAP = {"login": {IsAuthenticated}, "admin": {IsAdminUser}}


class APIView(View):
    permission_classes = ()

    def dispatch(self, request, *args, **kwargs):
        self.check_permissions(request)
        return super().dispatch(request, *args, **kwargs)

    def check_permissions(self, request):
        upload = getattr(settings, "KINDEDITOR_UPLOAD_PERMISSION", None)
        upload_perm = SETTINGS_PERMISSION_MAP.get(upload, set())
        permissions = set(self.permission_classes) | upload_perm
        if IsAuthenticated in permissions:
            if not request.user.is_authenticated:
                raise PermissionDenied
        elif IsAdminUser in permissions:
            if not (request.user and request.user.is_staff):
                raise PermissionDenied


class UploadImageForm(forms.ModelForm):
    class Meta:
        model = UploadImage
        fields = "__all__"


class ImageUploadView(APIView):
    def post(self, request):
        form = UploadImageForm(request.POST, request.FILES)
        if form.is_valid():
            obj = form.save()
            url = request.build_absolute_uri(obj.img.url)
            data = {"error": 0, "url": url}
            return JsonResponse(data, status=HTTP_201_CREATED)
        return JsonResponse(
            {
                "error": 1,
                "message": "{}:\n{}".format(_("Upload Error"), form.errors),
            },
            status=HTTP_400_BAD_REQUEST,
        )


image_upload = ImageUploadView.as_view()



__title__ = "django-kindeditor"
__description__ = "Django admin KindEditor integration."
__url__ = "https://github.com/waketzheng/django-kindeditor"
__version__ = "0.2.0"
__build__ = 0x022001
__author__ = "Waket Zheng"
__author_email__ = "waketzheng@gmail.com"
__license__ = "MIT"
__copyright__ = "Copyright 2019 Waket Zheng"
